summaryrefslogtreecommitdiffstats
path: root/kdvi/dviWidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdvi/dviWidget.cpp')
-rw-r--r--kdvi/dviWidget.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdvi/dviWidget.cpp b/kdvi/dviWidget.cpp
index 68f4b124..a0f43da3 100644
--- a/kdvi/dviWidget.cpp
+++ b/kdvi/dviWidget.cpp
@@ -22,8 +22,8 @@
#include "renderedDviPagePixmap.h"
#include "selection.h"
-DVIWidget::DVIWidget(TQWidget* tqparent, PageView* sv, DocumentPageCache* cache, const char* name)
- : DocumentWidget(tqparent, sv, cache, name)
+DVIWidget::DVIWidget(TQWidget* parent, PageView* sv, DocumentPageCache* cache, const char* name)
+ : DocumentWidget(parent, sv, cache, name)
{
}
@@ -74,7 +74,7 @@ void DVIWidget::mousePressEvent(TQMouseEvent* e)
e->accept();
}
// Call implementation from tqparent
DocumentWidget::mousePressEvent(e);
}
@@ -74,7 +74,7 @@ void DVIWidget::mousePressEvent(TQMouseEvent* e)
e->accept();
}
- // Call implementation from tqparent
+ // Call implementation from parent
DocumentWidget::mousePressEvent(e);
}